==> siglab-0.0.6.tar.gz: siglab-0.0.6/setup.py <==

from distutils.core import setup
setup(
  name = 'siglab',         # How you named your package folder (MyLib)
  packages = ['siglab'],   # Chose the same as "name"
  version = '0.0.6',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This OFDM function in sigplot gives us a complete visualization of how Orthogonal Frequency Division Multiplexing occurs.',   # Give a short description about your library
  author = 'Prakash Murugan',                   # Type in your name
  author_email = 'nprakashmcoonoor@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/PrakashMurugan17/sigplot',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/PrakashMurugan17/sigplot/archive/refs/tags/0.0.6.tar.gz',    # I explain this later on
  keywords = ['OFDM', 'QPSK', 'MODULATION','DEMODULATION'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy',
          'math','matplotlib'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> siglab-0.0.7.tar.gz: siglab-0.0.7/setup.py <==

from distutils.core import setup
setup(
  name = 'siglab',         # How you named your package folder (MyLib)
  packages = ['siglab'],   # Chose the same as "name"
  version = '0.0.7',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This OFDM function in sigplot gives us a complete visualization of how Orthogonal Frequency Division Multiplexing occurs.',   # Give a short description about your library
  author = 'Prakash Murugan',                   # Type in your name
  author_email = 'nprakashmcoonoor@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/PrakashMurugan17/siglab',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/PrakashMurugan17/siglab/archive/refs/tags/0.0.7.tar.gz',    # I explain this later on
  keywords = ['OFDM', 'QPSK', 'MODULATION','DEMODULATION'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy',
          'matplotlib'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
